@@ -46,8 +46,8 @@ Puppet::Type.newtype(:heat_config) do
     defaultto('<SERVICE DEFAULT>')
   end
 
-  autorequire(:package) do
-    'heat-common'
+  autorequire(:anchor) do
+    ['heat::install::end']
   end
 
 end
