@@ -97,9 +97,11 @@ describe 'heat::api' do
 
     context 'with $sync_db set to false in ::heat' do
       let :pre_condition do
-        "class {'heat':
-           keystone_password => 'password',
-           sync_db => false
+        "class { 'heat::keystone::authtoken':
+           password => 'a_big_secret',
+         }
+         class {'heat':
+           sync_db => false,
          }"
       end
 
@@ -109,32 +111,25 @@ describe 'heat::api' do
     end
   end
 
-  context 'on Debian platforms' do
-    let :facts do
-      @default_facts.merge({
-        :osfamily => 'Debian',
-      })
+  on_supported_os({
+    :supported_os   => OSDefaults.get_supported_os
+  }).each do |os,facts|
+    context "on #{os}" do
+      let (:facts) do
+        facts.merge!(OSDefaults.get_facts())
+      end
+
+      let :platform_params do
+        case facts[:osfamily]
+        when 'Debian'
+          { :api_service_name => 'heat-api' }
+        when 'RedHat'
+          { :api_service_name => 'openstack-heat-api' }
+        end
+      end
+
+      it_behaves_like 'heat-api'
     end
-
-    let :platform_params do
-      { :api_service_name => 'heat-api' }
-    end
-
-    it_configures 'heat-api'
-  end
-
-  context 'on RedHat platforms' do
-    let :facts do
-      @default_facts.merge({
-        :osfamily => 'RedHat',
-      })
-    end
-
-    let :platform_params do
-      { :api_service_name => 'openstack-heat-api' }
-    end
-
-    it_configures 'heat-api'
   end
 
 end
