@@ -3,7 +3,7 @@ require 'spec_helper'
 describe 'heat::db::mysql' do
 
   let :params do
-    { :password     => 's3cr3t',
+    { :password     => 'heatpass',
       :dbname       => 'heat',
       :user         => 'heat',
       :host         => 'localhost',
@@ -22,10 +22,10 @@ describe 'heat::db::mysql' do
     it 'creates a mysql database' do
       is_expected.to contain_openstacklib__db__mysql( params[:dbname] ).with(
         :user          => params[:user],
-        :password_hash => '*58C036CDA51D8E8BBBBF2F9EA5ABF111ADA444F0',
+        :password      => params[:password],
         :host          => params[:host],
         :charset       => params[:charset],
-        :collate       => 'utf8_general_ci',
+        :collate       => params[:collate],
       )
     end
   end
