@@ -14,6 +14,7 @@ describe 'heat::db' do
         :retry_interval          => '<SERVICE DEFAULT>',
         :max_overflow            => '<SERVICE DEFAULT>',
         :pool_timeout            => '<SERVICE DEFAULT>',
+        :mysql_enable_ndb        => '<SERVICE DEFAULT>',
       )}
 
       it { should contain_class('heat::db::sync') }
@@ -30,6 +31,7 @@ describe 'heat::db' do
           :database_db_max_retries          => '-1',
           :database_max_overflow            => '21',
           :database_pool_timeout            => '21',
+          :mysql_enable_ndb                 => true,
           :sync_db                          => false
         }
       end
@@ -45,6 +47,7 @@ describe 'heat::db' do
         :retry_interval          => '11',
         :max_overflow            => '21',
         :pool_timeout            => '21',
+        :mysql_enable_ndb        => true,
       )}
 
       it { should_not contain_class('heat::db::sync') }
