@@ -10,7 +10,14 @@ describe 'heat::db::sync' do
         :path        => '/usr/bin',
         :user        => 'heat',
         :refreshonly => 'true',
-        :logoutput   => 'on_failure'
+        :try_sleep   => 5,
+        :tries       => 10,
+        :logoutput   => 'on_failure',
+        :subscribe   => ['Anchor[heat::install::end]',
+                         'Anchor[heat::config::end]',
+                         'Anchor[heat::dbsync::begin]'],
+        :notify      => 'Anchor[heat::dbsync::end]',
+        :tag         => 'openstack-db',
       )
     end
 
@@ -27,7 +34,14 @@ describe 'heat::db::sync' do
           :path        => '/usr/bin',
           :user        => 'heat',
           :refreshonly => 'true',
-          :logoutput   => 'on_failure'
+          :try_sleep   => 5,
+          :tries       => 10,
+          :logoutput   => 'on_failure',
+          :subscribe   => ['Anchor[heat::install::end]',
+                           'Anchor[heat::config::end]',
+                           'Anchor[heat::dbsync::begin]'],
+          :notify      => 'Anchor[heat::dbsync::end]',
+          :tag         => 'openstack-db',
         )
         }
       end
@@ -40,12 +54,11 @@ describe 'heat::db::sync' do
     context "on #{os}" do
       let (:facts) do
         facts.merge(OSDefaults.get_facts({
-          :processorcount => 8,
           :concat_basedir => '/var/lib/puppet/concat'
         }))
       end
 
-      it_configures 'heat-dbsync'
+      it_behaves_like 'heat-dbsync'
     end
   end
 
